==> jc-1.4.0.tar.gz: soot/dava/DavaUnitPrinter.h <==
// public class soot.dava.DavaUnitPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1750eb5ba0ae1ec9 soot_AbstractUnitPrinter
// @dep_class 9dec04855c520603 soot_dava_DavaUnitPrinter

// header file dependencies
// @dep_header soot_AbstractUnitPrinter

#include "soot/AbstractUnitPrinter.h"

#ifndef _JC_soot_dava_DavaUnitPrinter_H_
#define _JC_soot_dava_DavaUnitPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_IdentityRef$object;

// Typedefs
typedef struct _jc_soot_dava_DavaUnitPrinter$sub_refs	_jc_soot_dava_DavaUnitPrinter$sub_refs;
typedef struct _jc_soot_dava_DavaUnitPrinter$sub_nonrefs	_jc_soot_dava_DavaUnitPrinter$sub_nonrefs;
typedef struct _jc_soot_dava_DavaUnitPrinter$refs	_jc_soot_dava_DavaUnitPrinter$refs;
typedef struct _jc_soot_dava_DavaUnitPrinter$nonrefs	_jc_soot_dava_DavaUnitPrinter$nonrefs;
typedef struct _jc_soot_dava_DavaUnitPrinter$object	_jc_soot_dava_DavaUnitPrinter$object;

typedef const struct _jc_soot_dava_DavaUnitPrinter$vmethods	_jc_soot_dava_DavaUnitPrinter$vmethods;
typedef const struct _jc_soot_dava_DavaUnitPrinter$vtable	_jc_soot_dava_DavaUnitPrinter$vtable;
typedef const struct _jc_soot_dava_DavaUnitPrinter$vtype	_jc_soot_dava_DavaUnitPrinter$vtype;

// Constructors
extern void _jc_soot_dava_DavaUnitPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *);

// Virtual methods
extern void _jc_soot_dava_DavaUnitPrinter$method$fieldRef$5a083ea7f0f1464f(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootField$object *);
extern void _jc_soot_dava_DavaUnitPrinter$method$identityRef$0496d0929fd4d759(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *);
extern void _jc_soot_dava_DavaUnitPrinter$method$literal$50b4e3e9b9524b5c(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_dava_DavaUnitPrinter$method$method$69518ff24fed1b70(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_dava_DavaUnitPrinter$method$type$741203f62135eae6(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_Type$object *);
extern void _jc_soot_dava_DavaUnitPrinter$method$unitRef$7aa3ccb1fb146e9f(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$fieldRef$5a083ea7f0f1464f;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$identityRef$0496d0929fd4d759;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$literal$50b4e3e9b9524b5c;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$method$69518ff24fed1b70;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$type$741203f62135eae6;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$unitRef$7aa3ccb1fb146e9f;

// Virtual methods structure
struct _jc_soot_dava_DavaUnitPrinter$vmethods {
	void	(*fieldRef$5a083ea7f0f1464f)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootField$object *);
	void	(*identityRef$0496d0929fd4d759)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *);
	void	(*literal$50b4e3e9b9524b5c)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_java_lang_String$object *);
	void	(*method$69518ff24fed1b70)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootMethod$object *);
	void	(*type$741203f62135eae6)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_Type$object *);
	void	(*unitRef$7aa3ccb1fb146e9f)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *, jboolean);
};

// Vtable
struct _jc_soot_dava_DavaUnitPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitPrinter$vmethods	soot_AbstractUnitPrinter;
	_jc_soot_dava_DavaUnitPrinter$vmethods	soot_dava_DavaUnitPrinter;
};

// Vtype
struct _jc_soot_dava_DavaUnitPrinter$vtype {
	_jc_type			type;
	_jc_soot_dava_DavaUnitPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_DavaUnitPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_DavaUnitPrinter$refs {
    _jc_soot_dava_DavaUnitPrinter$sub_refs	soot_dava_DavaUnitPrinter;
    _jc_soot_AbstractUnitPrinter$sub_refs	soot_AbstractUnitPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_DavaUnitPrinter$sub_nonrefs {
	jboolean	eatSpace;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_DavaUnitPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitPrinter$sub_nonrefs	soot_AbstractUnitPrinter;
    _jc_soot_dava_DavaUnitPrinter$sub_nonrefs	soot_dava_DavaUnitPrinter;
};

// Object instance structure
struct _jc_soot_dava_DavaUnitPrinter$object {
	_jc_soot_dava_DavaUnitPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_DavaUnitPrinter$vtype	*vtype;
	_jc_soot_dava_DavaUnitPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_DavaUnitPrinter$vtype _jc_soot_dava_DavaUnitPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_DavaUnitPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_DavaUnitPrinter$class_object;

#endif	/* _JC_soot_dava_DavaUnitPrinter_H_ */

==> jc-1.4.6.tar.gz: soot/dava/DavaUnitPrinter.h <==
// public class soot.dava.DavaUnitPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1750eb5ba0ae1ec9 soot_AbstractUnitPrinter
// @dep_class 9dec04855c520603 soot_dava_DavaUnitPrinter

// header file dependencies
// @dep_header soot_AbstractUnitPrinter

#include "soot/AbstractUnitPrinter.h"

#ifndef _JC_soot_dava_DavaUnitPrinter_H_
#define _JC_soot_dava_DavaUnitPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_IdentityRef$object;

// Typedefs
typedef struct _jc_soot_dava_DavaUnitPrinter$sub_refs	_jc_soot_dava_DavaUnitPrinter$sub_refs;
typedef struct _jc_soot_dava_DavaUnitPrinter$sub_nonrefs	_jc_soot_dava_DavaUnitPrinter$sub_nonrefs;
typedef struct _jc_soot_dava_DavaUnitPrinter$refs	_jc_soot_dava_DavaUnitPrinter$refs;
typedef struct _jc_soot_dava_DavaUnitPrinter$nonrefs	_jc_soot_dava_DavaUnitPrinter$nonrefs;
typedef struct _jc_soot_dava_DavaUnitPrinter$object	_jc_soot_dava_DavaUnitPrinter$object;

typedef const struct _jc_soot_dava_DavaUnitPrinter$vmethods	_jc_soot_dava_DavaUnitPrinter$vmethods;
typedef const struct _jc_soot_dava_DavaUnitPrinter$vtable	_jc_soot_dava_DavaUnitPrinter$vtable;
typedef const struct _jc_soot_dava_DavaUnitPrinter$vtype	_jc_soot_dava_DavaUnitPrinter$vtype;

// Constructors
extern void _jc_soot_dava_DavaUnitPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_DavaUnitPrinter$method$fieldRef$5a083ea7f0f1464f(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaUnitPrinter$method$identityRef$0496d0929fd4d759(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaUnitPrinter$method$literal$50b4e3e9b9524b5c(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaUnitPrinter$method$method$69518ff24fed1b70(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaUnitPrinter$method$type$741203f62135eae6(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaUnitPrinter$method$unitRef$7aa3ccb1fb146e9f(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$fieldRef$5a083ea7f0f1464f;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$identityRef$0496d0929fd4d759;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$literal$50b4e3e9b9524b5c;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$method$69518ff24fed1b70;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$type$741203f62135eae6;
extern _jc_method _jc_soot_dava_DavaUnitPrinter$method_info$unitRef$7aa3ccb1fb146e9f;

// Virtual methods structure
struct _jc_soot_dava_DavaUnitPrinter$vmethods {
	void	(*fieldRef$5a083ea7f0f1464f)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	void	(*identityRef$0496d0929fd4d759)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*literal$50b4e3e9b9524b5c)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*method$69518ff24fed1b70)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*type$741203f62135eae6)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	void	(*unitRef$7aa3ccb1fb146e9f)(_jc_env *, struct _jc_soot_dava_DavaUnitPrinter$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_DavaUnitPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitPrinter$vmethods	soot_AbstractUnitPrinter;
	_jc_soot_dava_DavaUnitPrinter$vmethods	soot_dava_DavaUnitPrinter;
};

// Vtype
struct _jc_soot_dava_DavaUnitPrinter$vtype {
	_jc_type			type;
	_jc_soot_dava_DavaUnitPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_DavaUnitPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_DavaUnitPrinter$refs {
    _jc_soot_dava_DavaUnitPrinter$sub_refs	soot_dava_DavaUnitPrinter;
    _jc_soot_AbstractUnitPrinter$sub_refs	soot_AbstractUnitPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_DavaUnitPrinter$sub_nonrefs {
	jboolean	eatSpace;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_DavaUnitPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitPrinter$sub_nonrefs	soot_AbstractUnitPrinter;
    _jc_soot_dava_DavaUnitPrinter$sub_nonrefs	soot_dava_DavaUnitPrinter;
};

// Object instance structure
struct _jc_soot_dava_DavaUnitPrinter$object {
	_jc_soot_dava_DavaUnitPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_DavaUnitPrinter$vtype	*vtype;
	_jc_soot_dava_DavaUnitPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_DavaUnitPrinter$vtype _jc_soot_dava_DavaUnitPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_DavaUnitPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_DavaUnitPrinter$class_object;

#endif	/* _JC_soot_dava_DavaUnitPrinter_H_ */
